.. image:: https://travis-ci.org/enthought/okonomiyaki.png?branch=master
    :target: https://travis-ci.org/enthought/okonomiyaki

Okonomiyaki is an experimental library aimed at consolidating a lot of our
low-level code used for Enthought's eggs.

The library contains code for the following:

        - producing enpkg-compatible egg from a tree + metadata
        - traitlets-based models for eggs metadata, as well as our legacy
          metadata
